@@ -13,7 +13,6 @@
 #include <KCalendarCore/Event>
 #include <QVariantMap>
 
-class CalindoriConfig;
 class AlarmChecker;
 
 class LocalCalendar : public QObject
@@ -23,19 +22,19 @@ class LocalCalendar : public QObject
     Q_PROPERTY(QString ownerName READ ownerName WRITE setOwnerName NOTIFY ownerNameChanged)
     Q_PROPERTY(QString ownerEmail READ ownerEmail WRITE setOwnerEmail NOTIFY ownerEmailChanged)
     Q_PROPERTY(bool isExternal READ isExternal NOTIFY isExternalChanged)
-    Q_PROPERTY(QSharedPointer<KCalendarCore::Calendar> calendar READ calendar WRITE setCalendar NOTIFY calendarChanged)
+    Q_PROPERTY(KCalendarCore::Calendar *calendar READ calendarRaw NOTIFY calendarChanged)
 
 public:
     explicit LocalCalendar(QObject *parent = nullptr);
     ~LocalCalendar() override;
 
     KCalendarCore::Calendar::Ptr calendar();
+    KCalendarCore::Calendar *calendarRaw() const;
     QString name() const;
     QString ownerName() const;
     QString ownerEmail() const;
     bool isExternal() const;
 
-    void setCalendar(KCalendarCore::Calendar::Ptr calendar);
     void setName(const QString &calendarName);
     void setOwnerName(const QString &ownerName);
     void setOwnerEmail(const QString &ownerEmail);
@@ -66,7 +65,6 @@ private:
     KCalendarCore::FileStorage::Ptr m_cal_storage;
     QString m_name;
     QString m_fullpath;
-    CalindoriConfig *m_config;
     QDateTime m_fs_sync_dt;
     AlarmChecker *m_alarm_checker;
 };
